/*
   Prototypes of NAG Fortran (M22) routines:
      E04UJF, E04UGF, E04UEF, E04UFF, E04UGF, A00AAF, A00ACF
   extracted & adjusted from the official file nagmk22.h
  
   last update: 05/11/2010 by JF
*/

#ifndef __NAGE04_INCLUDED
#define __NAGE04_INCLUDED


#ifndef NAG_TYPES
  typedef int Integer;
  typedef int logical;
#else
  typedef NAG_F77_int logical;
#endif

#define CONST const

#ifdef __cplusplus
#define VOID
#else
#define VOID void
#endif

#if defined USE_STDCALL
#define NAG_CALL __stdcall
#else
#define NAG_CALL 
#endif

typedef int Charlen;

#ifdef __cplusplus
extern "C" {
#endif

#if !defined(USE_STDCALL)
  // ok __cdecl but linux names or windows?
#ifndef WINNAMES
  // expects linux names & __cdecl & length of stings is passed at the end

#define  A00AAF a00aaf_
#define  A00ACF a00acf_
#define  E04UEF e04uef_
#define  E04UJF e04ujf_
#define  E04UFF e04uff_
// Note that E04UGF has 2 string parameters, by default I call it
//     E04UGF(...,char,len,char,len,...)
// but on Linux we need to change it to 
//     e04ugf_(...,char,char,...,len,len) 
// (so not just a change of the mangled name)
//#define  E04UGF e04ugf_
#define \
E04UGF(confun, objfun, n, m, ncnln, nonln, njnln, iobj, nnz, a, ha, ka, bl, bu, start, length_start, nname, names, length_names, ns, xs, istate, clamda, miniz, minz, ninf, sinf, obj, iz, leniz, z, lenz, iuser, ruser, ifail)  \
e04ugf_(confun, objfun, n, m, ncnln, nonln, njnln, iobj, nnz, a, ha, ka, bl, bu, start, nname, names, ns, xs, istate, clamda, miniz, minz, ninf, sinf, obj, iz, leniz, z, lenz, iuser, ruser, ifail, length_start, length_names) 

#else
  // __cdecl, win names but length of strings at the end
#define \
E04UGF(confun, objfun, n, m, ncnln, nonln, njnln, iobj, nnz, a, ha, ka, bl, bu, start, length_start, nname, names, length_names, ns, xs, istate, clamda, miniz, minz, ninf, sinf, obj, iz, leniz, z, lenz, iuser, ruser, ifail)  \
E04UGF(confun, objfun, n, m, ncnln, nonln, njnln, iobj, nnz, a, ha, ka, bl, bu, start, nname, names, ns, xs, istate, clamda, miniz, minz, ninf, sinf, obj, iz, leniz, z, lenz, iuser, ruser, ifail, length_start, length_names) 


#endif

#endif

extern void NAG_CALL A00AAF(VOID);

extern logical NAG_CALL A00ACF(VOID);

extern void NAG_CALL E04UEF(CONST char * str, CONST Charlen length_str);

extern void NAG_CALL E04UJF(CONST char * str,  CONST Charlen length_str);

extern void NAG_CALL E04UFF(
  Integer *irevcm,
  CONST Integer *n,
  CONST Integer *nclin,
  CONST Integer *ncnln,
  CONST Integer *lda,
  CONST Integer *ldcj,
  CONST Integer *ldr,
  CONST double a[] /* 2 dimension */,
  CONST double bl[] /* 1 dimension */,
  CONST double bu[] /* 1 dimension */,
  Integer *iter,
  Integer istate[] /* 1 dimension */,
  double c[] /* 1 dimension */,
  double cjac[] /* 2 dimension */,
  double clamda[] /* 1 dimension */,
  double *objf,
  double objgrd[] /* 1 dimension */,
  double r[] /* 2 dimension */,
  double x[] /* 1 dimension */,
  Integer needc[] /* 1 dimension */,
  Integer iwork[] /* 1 dimension */,
  CONST Integer *liwork,
  double work[] /* 1 dimension */,
  CONST Integer *lwork,
  Integer *ifail
);

// expect (...char,len,char,len,...) argument order, if it is different, 
// a macro will change this declaration as well
extern void NAG_CALL E04UGF(
  void (NAG_CALL *confun)(Integer *, CONST Integer *, CONST Integer *,
    CONST Integer *, CONST double[], double[], double[], CONST Integer *,
    Integer[], double[]),
  void (NAG_CALL *objfun)(Integer *, CONST Integer *, CONST double[], double *,
    double[], CONST Integer *, Integer[], double[]),
  CONST Integer *n,
  CONST Integer *m,
  CONST Integer *ncnln,
  CONST Integer *nonln,
  CONST Integer *njnln,
  CONST Integer *iobj,
  CONST Integer *nnz,
  double a[] /* 1 dimension */,
  CONST Integer ha[] /* 1 dimension */,
  CONST Integer ka[] /* 1 dimension */,
  double bl[] /* 1 dimension */,
  double bu[] /* 1 dimension */,
  CONST char * start,
  CONST Charlen length_start,
  CONST Integer *nname,
  CONST char names[] /* 1 dimension */,
  CONST Charlen length_names,
  Integer *ns,
  double xs[] /* 1 dimension */,
  Integer istate[] /* 1 dimension */,
  double clamda[] /* 1 dimension */,
  Integer *miniz,
  Integer *minz,
  Integer *ninf,
  double *sinf,
  double *obj,
  Integer iz[] /* 1 dimension */,
  CONST Integer *leniz,
  double z[] /* 1 dimension */,
  CONST Integer *lenz,
  Integer iuser[] /* 1 dimension */,
  double ruser[] /* 1 dimension */,
  Integer *ifail
);

#ifdef __cplusplus
}
#endif

#endif
